==> monodevelop_2.2.1+dfsg.orig.tar.gz: monodevelop-2.2.1/src/addins/AspNet/MonoDevelop.AspNet/MonoDevelop.AspNet/AspNetToolboxProvider.cs <==
//
// ToolboxProvider.cs: Provides default ASP.NET controls to the toolbox.
//
// Authors:
//   Michael Hutchinson <m.j.hutchinson@gmail.com>
//
// Copyright (C) 2006 Michael Hutchinson
//
//
// This source code is licenced under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.IO;
using System.Collections.Generic;
using MonoDevelop.Core;
using MonoDevelop.DesignerSupport.Toolbox;
using MonoDevelop.Ide.Gui;
using MonoDevelop.Core.Assemblies;


namespace MonoDevelop.AspNet
{
	
	public class AspNetToolboxProvider : IToolboxDefaultProvider
	{
		public IEnumerable<string> GetDefaultFiles ()
		{
			string location;
			
			TargetFramework fx = Runtime.SystemAssemblyService.GetTargetFramework ("1.1");
			
			location = Runtime.SystemAssemblyService.DefaultAssemblyContext.GetAssemblyLocation ("System.Web, Version=1.0.5000.0", fx);
			if (!string.IsNullOrEmpty (location))
				yield return location;
			
			fx = Runtime.SystemAssemblyService.GetTargetFramework ("3.5");
			
			location = Runtime.SystemAssemblyService.DefaultAssemblyContext.GetAssemblyLocation ("System.Web, Version=2.0.0.0", fx);
			if (!string.IsNullOrEmpty (location))
				yield return location;
			
			location = Runtime.SystemAssemblyService.DefaultAssemblyContext.GetAssemblyLocation ("System.Web.Extensions", fx);
			if (!string.IsNullOrEmpty (location))
				yield return location;
		}
		
		public IEnumerable<ItemToolboxNode> GetDefaultItems ()
		{
			return null;
		}
	}
}

==> monodevelop_2.4+dfsg.orig.tar.gz: monodevelop-2.4/src/addins/AspNet/MonoDevelop.AspNet/MonoDevelop.AspNet/AspNetToolboxProvider.cs <==
//
// ToolboxProvider.cs: Provides default ASP.NET controls to the toolbox.
//
// Authors:
//   Michael Hutchinson <m.j.hutchinson@gmail.com>
//
// Copyright (C) 2006 Michael Hutchinson
//
//
// This source code is licenced under The MIT License:
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Linq;
using System.IO;
using System.Collections.Generic;
using MonoDevelop.Core;
using MonoDevelop.DesignerSupport.Toolbox;
using MonoDevelop.Ide.Gui;
using MonoDevelop.Core.Assemblies;


namespace MonoDevelop.AspNet
{
	
	public class AspNetToolboxProvider : IToolboxDefaultProvider
	{
		public IEnumerable<string> GetDefaultFiles ()
		{
			return GetFxAssemblies ().Where (s => !string.IsNullOrEmpty (s));
		}
		
		IEnumerable<string> GetFxAssemblies ()
		{
			var ctx = Runtime.SystemAssemblyService.DefaultAssemblyContext;
			
			TargetFramework fx = Runtime.SystemAssemblyService.GetTargetFramework ("1.1");
			
			yield return ctx.GetAssemblyLocation ("System.Web, Version=1.0.5000.0", fx);
			
			fx = Runtime.SystemAssemblyService.GetTargetFramework ("3.5");
			
			yield return ctx.GetAssemblyLocation ("System.Web, Version=2.0.0.0", fx);
			
			fx = Runtime.SystemAssemblyService.GetTargetFramework ("2.0");
			
			yield return ctx.GetAssemblyLocation ("System.Web.Extensions, Version=3.5.0.0", fx);
			yield return ctx.GetAssemblyLocation ("System.Web.Mvc, Version=1.0.0.0", fx);
			
			fx = Runtime.SystemAssemblyService.GetTargetFramework ("4.0");
			
			yield return ctx.GetAssemblyLocation ("System.Web, Version=4.0.0.0", fx);
			yield return ctx.GetAssemblyLocation ("System.Web.Extensions, Version=4.0.0.0", fx);
			yield return ctx.GetAssemblyLocation ("System.Web.Mvc, Version=2.0.0.0", fx);
		}
		
		public IEnumerable<ItemToolboxNode> GetDefaultItems ()
		{
			return null;
		}
	}
}
